#!/usr/bin/env python

"A test of cookies."

import WebStack.Generic
import time

class CookiesResource:

    "A resource adding and removing cookies."

    def respond(self, trans):
        trans.set_content_type(WebStack.Generic.ContentType("text/html"))

        # Get the fields and choose an action.

        fields = trans.get_fields_from_path()

        cookie_name_list = fields.get("name") or ["test"]
        cookie_value_list = fields.get("value") or ["test"]
        cookie_path_list = fields.get("path") or ["/"]
        cookie_expires_list = fields.get("expires") or ["60"]

        cookie_name = cookie_name_list[0]
        cookie_value = cookie_value_list[0]
        cookie_path = cookie_path_list[0]
        cookie_expires = int(cookie_expires_list[0])

        message = "No action taken - use add or delete to change the cookies."

        if fields.has_key("add"):
            trans.set_cookie_value(
                cookie_name,
                cookie_value,
                cookie_path,
                time.time() + cookie_expires
            )
            message = "Cookie %s added!" % cookie_name

        elif fields.has_key("delete"):
            trans.delete_cookie(cookie_name)
            message = "Cookie %s deleted!" % cookie_name

        # Get some information.

        out = trans.get_response_stream()
        out.write("""
<html>
  <head>
    <title>Cookies Example</title>
  </head>
  <body>
    <h1>Cookies</h1>
    <p>%s</p>
    <ul>
      %s
    </ul>
    <h2>Cookie</h2>
    <p>Name specified: %s</p>
    <p>Value found: %s</p>
  </body>
</html>
""" % (
    message,
    self._format_cookies(trans.get_cookies()),
    cookie_name,
    trans.get_cookie(cookie_name),
))

    def _format_cookies(self, d):
        return "".join([
            "<dt>%s</dt><dd>%s</dd>" % (key, value.value)
            for key, value in d.items()
        ])

    def _format_list(self, l):
        return "".join([
            "<li>%s</li>" % value
            for value in l
        ])

# vim: tabstop=4 expandtab shiftwidth=4
